@@ -2,11 +2,11 @@ import inspect
 from typing import TypeVar, Type
 
 from cloudrail.knowledge.context.mergeable import Mergeable
-from cloudrail.knowledge.context.terraform_action_type import TerraformActionType
-from cloudrail.knowledge.context.terraform_state import TerraformState
+from cloudrail.knowledge.context.iac_action_type import IacActionType
+from cloudrail.knowledge.context.iac_state import IacState
 
 
-_T = TypeVar('_T', bound=Mergeable)
+_T = TypeVar('_T')
 
 
 def create_empty_entity(class_type: Type[_T], **kwargs) -> _T:
@@ -24,9 +24,12 @@ def create_empty_entity(class_type: Type[_T], **kwargs) -> _T:
     for param in list(signature.parameters)[1:]:
         params[param] = None
     params.update(kwargs)
-    return class_type(**params)
+    resource = class_type(**params)
+    if isinstance(resource, Mergeable):
+        add_terraform_state(resource, resource.__class__.__name__, True)
+    return resource
 
 
 def add_terraform_state(resource: Mergeable, friendly_name: str, as_new_resource: bool = True):
-    action_type = TerraformActionType.CREATE if as_new_resource else TerraformActionType.UPDATE
-    resource.terraform_state = TerraformState(friendly_name, action_type, None, as_new_resource)
+    action_type = IacActionType.CREATE if as_new_resource else IacActionType.UPDATE
+    resource.iac_state = IacState(friendly_name, action_type, None, as_new_resource)
