@@ -68,7 +68,7 @@ class ApiGatewayMethodSettings(AwsResource):
         return False
 
     def to_drift_detection_object(self) -> dict:
-        return {'tags': self.tags, 'stage_name': self.stage_name,
+        return {'stage_name': self.stage_name,
                 'method_path': self.method_path,
                 'http_method': self.http_method.value,
                 'caching_enabled': self.caching_enabled,
