@@ -2,6 +2,7 @@ from typing import List, Optional
 from cloudrail.knowledge.context.aws.resources.apigateway.rest_api_gw_mapping import RestApiGwMapping
 from cloudrail.knowledge.context.aws.resources.service_name import AwsServiceName, AwsServiceType, AwsServiceAttributes
 from cloudrail.knowledge.context.aws.resources.aws_resource import AwsResource
+from cloudrail.knowledge.utils.tags_utils import filter_tags
 
 
 class RestApiGwDomain(AwsResource):
@@ -42,5 +43,5 @@ class RestApiGwDomain(AwsResource):
         return True
 
     def to_drift_detection_object(self) -> dict:
-        return {'tags': self.tags, 'domain_name': self.domain_name,
+        return {'tags': filter_tags(self.tags), 'domain_name': self.domain_name,
                 'security_policy': self.security_policy}
