@@ -54,7 +54,7 @@ class CloudHsmV2Hsm(AwsResource):
         return False
 
     def to_drift_detection_object(self) -> dict:
-        return {'tags': self.tags, 'cluster_id': self.cluster_id,
+        return {'cluster_id': self.cluster_id,
                 'subnet_id': self.subnet_id,
                 'availability_zone': self.availability_zone,
                 'hsm_state': self.hsm_state}
