@@ -50,4 +50,4 @@ class Ec2Image(AwsResource):
         return False
 
     def to_drift_detection_object(self) -> dict:
-        return {'tags': self.tags, }
+        return {}
