@@ -3,6 +3,7 @@ from typing import List
 from cloudrail.knowledge.context.aws.resources.ec2.network_acl_rule import NetworkAclRule
 from cloudrail.knowledge.context.aws.resources.aws_resource import AwsResource
 from cloudrail.knowledge.context.aws.resources.service_name import AwsServiceName
+from cloudrail.knowledge.utils.tags_utils import filter_tags
 
 
 class NetworkAcl(AwsResource):
@@ -72,7 +73,7 @@ class NetworkAcl(AwsResource):
         return True
 
     def to_drift_detection_object(self) -> dict:
-        return {'tags': self.tags, 'vpc_id': self.vpc_id,
+        return {'tags': filter_tags(self.tags), 'vpc_id': self.vpc_id,
                 'is_default': self.is_default,
                 'name': self.name,
                 'subnet_ids': self.subnet_ids,
