@@ -11,6 +11,7 @@ from cloudrail.knowledge.context.aws.resources.aws_resource import AwsResource
 from cloudrail.knowledge.context.aws.resources.ec2.route_table import RouteTable
 from cloudrail.knowledge.context.aws.resources.ec2.security_group import SecurityGroup
 from cloudrail.knowledge.context.aws.resources.ec2.vpc_endpoint import VpcEndpoint
+from cloudrail.knowledge.utils.tags_utils import filter_tags
 
 
 @dataclass
@@ -50,7 +51,7 @@ class VpcAttribute(AwsResource):
         return False
 
     def to_drift_detection_object(self) -> dict:
-        return {'tags': self.tags, 'vpc_id': self.vpc_id,
+        return {'vpc_id': self.vpc_id,
                 'attribute_name': self.attribute_name,
                 'enable': self.enable}
 
@@ -133,9 +134,7 @@ class Vpc(AwsResource):
         return True
 
     def to_drift_detection_object(self) -> dict:
-        return {'tags': self.tags, 'cidr_block': self.cidr_block,
+        return {'tags': filter_tags(self.tags), 'cidr_block': self.cidr_block,
                 'ipv6_cidr_block': self.ipv6_cidr_block,
                 'name': self.name,
-                'is_default': self.is_default,
-                'enable_dns_support': self.enable_dns_support,
-                'enable_dns_hostnames': self.enable_dns_hostnames}
+                'is_default': self.is_default}
