@@ -3,6 +3,7 @@ from typing import List, Optional
 from cloudrail.knowledge.context.aws.resources.aws_policied_resource import PoliciedResource
 from cloudrail.knowledge.context.aws.resources.kms.kms_key import KmsKey
 from cloudrail.knowledge.context.aws.resources.service_name import AwsServiceName
+from cloudrail.knowledge.utils.tags_utils import filter_tags
 
 
 class EcrRepository(PoliciedResource):
@@ -59,7 +60,7 @@ class EcrRepository(PoliciedResource):
         return True
 
     def to_drift_detection_object(self) -> dict:
-        return {'tags': self.tags, 'repo_name': self.repo_name,
+        return {'tags': filter_tags(self.tags), 'repo_name': self.repo_name,
                 'image_tag_mutability': self.image_tag_mutability,
                 'is_image_scan_on_push': self.is_image_scan_on_push,
                 'encryption_type': self.encryption_type,
