@@ -64,7 +64,7 @@ class EfsMountTarget(NetworkEntity):
         return False
 
     def to_drift_detection_object(self) -> dict:
-        return {'tags': self.tags, 'efs_id': self.efs_id,
+        return {'efs_id': self.efs_id,
                 'eni_id': self.eni_id,
                 'subnet_id': self.subnet_id,
                 'security_groups_ids': self.security_groups_ids}
