@@ -2,6 +2,7 @@ from typing import List
 
 from cloudrail.knowledge.context.aws.resources.aws_policied_resource import PoliciedResource
 from cloudrail.knowledge.context.aws.resources.service_name import AwsServiceName
+from cloudrail.knowledge.utils.tags_utils import filter_tags
 
 
 class GlacierVault(PoliciedResource):
@@ -44,4 +45,4 @@ class GlacierVault(PoliciedResource):
         return True
 
     def to_drift_detection_object(self) -> dict:
-        return {'tags': self.tags, 'vault_name': self.vault_name}
+        return {'tags': filter_tags(self.tags), 'vault_name': self.vault_name}
