@@ -29,4 +29,4 @@ class GlueDataCatalogPolicy(Policy):
         return 'Glue Data Catalog resource policy'
 
     def to_drift_detection_object(self) -> dict:
-        return {'tags': self.tags, 'policy_statements': [statement.to_dict() for statement in self.statements]}
+        return {'policy_statements': [statement.to_dict() for statement in self.statements]}
