@@ -5,6 +5,7 @@ from cloudrail.knowledge.context.aws.resources.networking_config.inetwork_config
 from cloudrail.knowledge.context.aws.resources.service_name import AwsServiceName
 from cloudrail.knowledge.context.aws.resources.networking_config.network_configuration import NetworkConfiguration
 from cloudrail.knowledge.context.aws.resources.networking_config.network_entity import NetworkEntity
+from cloudrail.knowledge.utils.tags_utils import filter_tags
 
 
 class NeptuneInstance(NetworkEntity, INetworkConfiguration):
@@ -65,7 +66,8 @@ class NeptuneInstance(NetworkEntity, INetworkConfiguration):
         return True
 
     def to_drift_detection_object(self) -> dict:
-        return {'tags': self.tags, 'name': self.name,
+        return {'tags': filter_tags(self.tags),
+                'name': self.name,
                 'port': self.port,
                 'cluster_identifier': self.cluster_identifier,
                 'publicly_accessible': self.network_configuration.assign_public_ip}
