@@ -13,6 +13,7 @@ from cloudrail.knowledge.context.aws.resources.s3.public_access_block_settings i
 from cloudrail.knowledge.context.aws.resources.s3.s3_acl import GranteeTypes, S3ACL
 from cloudrail.knowledge.context.aws.resources.s3.s3_bucket_access_point import S3BucketAccessPoint, S3BucketAccessPointNetworkOriginType
 from cloudrail.knowledge.context.aws.resources.s3.s3_bucket_encryption import S3BucketEncryption
+from cloudrail.knowledge.utils.tags_utils import filter_tags
 
 
 class S3Bucket(ConnectionInstance, PoliciedResource):
@@ -89,7 +90,8 @@ class S3Bucket(ConnectionInstance, PoliciedResource):
         return len(self.publicly_allowing_resources) > 0
 
     def to_drift_detection_object(self) -> dict:
-        return {'tags': self.tags, 'bucket_name': self.bucket_name,
+        return {'tags':  filter_tags(self.tags),
+                'bucket_name': self.bucket_name,
                 'encryption_data': self.encryption_data and self.encryption_data.to_drift_detection_object(),
                 'versioning_data': self.versioning_data and self.versioning_data.to_drift_detection_object(),
                 'exposed_to_agw_methods': [method.to_drift_detection_object() for method in self.exposed_to_agw_methods],
