@@ -4,6 +4,7 @@ from typing import List, Optional
 from cloudrail.knowledge.context.aws.resources.aws_policied_resource import PoliciedResource
 from cloudrail.knowledge.context.aws.resources.kms.kms_key import KmsKey
 from cloudrail.knowledge.context.aws.resources.service_name import AwsServiceName
+from cloudrail.knowledge.utils.tags_utils import filter_tags
 
 
 class SqsQueue(PoliciedResource):
@@ -55,6 +56,7 @@ class SqsQueue(PoliciedResource):
         return True
 
     def to_drift_detection_object(self) -> dict:
-        return {'tags': self.tags, 'queue_name': self.queue_name,
+        return {'tags': filter_tags(self.tags),
+                'queue_name': self.queue_name,
                 'encrypted_at_rest': self.encrypted_at_rest,
                 'resource_based_policy': self.resource_based_policy and self.resource_based_policy.to_drift_detection_object()}
