@@ -31,5 +31,5 @@ class AzureNetworkInterfaceApplicationSecurityGroupAssociation(AzureResource):
         return False
 
     def to_drift_detection_object(self) -> dict:
-        return {'tags': self.tags, 'network_interface_id': self.network_interface_id,
+        return {'network_interface_id': self.network_interface_id,
                 'application_security_group_id': self.application_security_group_id}
