@@ -29,4 +29,4 @@ class AzureSubnet(AzureResource):
         return [self.get_id()]
 
     def to_drift_detection_object(self) -> dict:
-        return {'tags': self.tags, 'name': self.name}
+        return {'name': self.name}
