@@ -1,23 +1,29 @@
 from typing import Optional, List
 from cloudrail.knowledge.context.azure.resources.azure_resource import AzureResource
 from cloudrail.knowledge.context.azure.resources.constants.azure_resource_type import AzureResourceType
+from cloudrail.knowledge.context.azure.resources.i_managed_identity_resource import IManagedIdentityResource
+from cloudrail.knowledge.context.azure.resources.managed_identities.azure_managed_identity import AzureManagedIdentity
 from cloudrail.knowledge.context.azure.resources.webapp.azure_app_service_config import AzureAppServiceConfig
 
 
-class AzureAppService(AzureResource):
+class AzureAppService(AzureResource, IManagedIdentityResource):
     """
         Attributes:
             name: The name of this AppService.
             app_service_config: App service configuration.
             https_only: Indicates if the App Service only be accessed via HTTPS.
             client_cert_required: Indicate if client certificates are required in Web App.
+            identities_ids: The managed identities associated with the app service.
+            managed_identities: all managed identities associate with the app service.
     """
-    def __init__(self, name: str, https_only: bool, client_cert_required: bool):
+    def __init__(self, name: str, https_only: bool, client_cert_required: bool, identities_ids: List[str]):
         super().__init__(AzureResourceType.AZURERM_APP_SERVICE)
         self.name: str = name
         self.app_service_config: AzureAppServiceConfig = None
         self.https_only: bool = https_only
         self.client_cert_required: bool = client_cert_required
+        self.identities_ids: List[str] = identities_ids
+        self.managed_identities: List[AzureManagedIdentity] = []
 
     def get_keys(self) -> List[str]:
         return [self.get_name()]
@@ -38,3 +44,9 @@ class AzureAppService(AzureResource):
                 'https_only': self.https_only,
                 'client_cert_required': self.client_cert_required,
                 'app_service_config': self.app_service_config and self.app_service_config.to_drift_detection_object()}
+
+    def get_managed_identities(self) -> List[AzureManagedIdentity]:
+        return self.managed_identities
+
+    def get_managed_identities_ids(self) -> List[str]:
+        return self.identities_ids
