@@ -1,4 +1,4 @@
-from cloudrail.knowledge.context.azure.resources.keyvault.azure_monitor_diagnostic_setting import AzureMonitorDiagnosticSetting, \
+from cloudrail.knowledge.context.azure.resources.monitor.azure_monitor_diagnostic_setting import AzureMonitorDiagnosticSetting, \
     AzureMonitorDiagnosticLogsSettings, AzureMonitorDiagnosticLogsRetentionPolicySettings
 
 from cloudrail.knowledge.context.azure.resources_builders.scanner.base_azure_scanner_builder import BaseAzureScannerBuilder
@@ -7,7 +7,7 @@ from cloudrail.knowledge.context.azure.resources_builders.scanner.base_azure_sca
 class MonitorDiagnosticSettingBuilder(BaseAzureScannerBuilder):
 
     def get_file_name(self) -> str:
-        return 'key-vault-diagnostic-settings.json'
+        return '*-diagnostic-settings.json'
 
     def do_build(self, attributes: dict) -> AzureMonitorDiagnosticSetting:
         # The target resource id is the partial id of the monitoring diagnostic settings, as it is tightly coupled to the target
@@ -20,5 +20,6 @@ class MonitorDiagnosticSettingBuilder(BaseAzureScannerBuilder):
             if raw_retention_policy := raw_logs_block.get('retentionPolicy'):
                 retention_policy = AzureMonitorDiagnosticLogsRetentionPolicySettings(raw_retention_policy['enabled'], raw_retention_policy['days'])
             log_settings = AzureMonitorDiagnosticLogsSettings(logs_enabled, retention_policy)
+        storage_account_id = attributes['properties'].get('storageAccountId')
 
-        return AzureMonitorDiagnosticSetting(name=attributes['name'], target_resource_id=target_resource_id, logs_settings=log_settings)
+        return AzureMonitorDiagnosticSetting(name=attributes['name'], target_resource_id=target_resource_id, logs_settings=log_settings, storage_account_id=storage_account_id)
