@@ -2,6 +2,7 @@ from typing import Dict, List
 
 from cloudrail.knowledge.rules.base_rule import BaseRule
 from cloudrail.knowledge.rules.gcp.context_aware.compute_ssl_policy_proxy_no_weak_ciphers_rule import ComputeSslPolicyProxyNoWeakCiphersRule
+from cloudrail.knowledge.rules.gcp.context_aware.storage_bucket_is_not_publicly_accessible_rule import StorageBucketIsNotPubliclyAccessibleRule
 from cloudrail.knowledge.rules.gcp.non_context_aware.cloud_dns_no_rsasha1_used_rules import CloudDnsNoRsasha1UsedRule
 from cloudrail.knowledge.rules.gcp.non_context_aware.compute_instance_ensure_no_ip_forwarding_rule import \
     ComputeInstanceEnsureNoIpForwardingRule
@@ -63,5 +64,6 @@ class GcpRulesLoader(AbstractRulesLoader):
             ComputeSubNetworkEnableFlowLogsRule(),
             ContainerClusterUseRbacUsersRule(),
             PublicAccessVpcRdpPortRule(),
+            StorageBucketIsNotPubliclyAccessibleRule(),
         ]
         return {rule.get_id(): rule for rule in rules}
