@@ -5,14 +5,14 @@ from typing import Set, List, Optional, Tuple
 
 from netaddr import IPNetwork, IPSet
 
-from cloudrail.knowledge.context.aws.ec2.network_acl_rule import NetworkAclRule, RuleAction
-from cloudrail.knowledge.context.aws.ec2.ec2_instance import Ec2Instance
-from cloudrail.knowledge.context.aws.ecs.ecs_task_definition import IEcsInstance, EcsTaskDefinition
-from cloudrail.knowledge.context.aws.ec2.network_interface import NetworkInterface
-from cloudrail.knowledge.context.aws.ec2.route import RouteTargetType, Route
-from cloudrail.knowledge.context.aws.ec2.subnet import Subnet
-from cloudrail.knowledge.context.aws.ec2.transit_gateway import TransitGateway
-from cloudrail.knowledge.context.aws.ec2.transit_gateway_route import TransitGatewayRouteState, TransitGatewayRoute, TransitGatewayRouteType
+from cloudrail.knowledge.context.aws.resources.ec2.network_acl_rule import NetworkAclRule, RuleAction
+from cloudrail.knowledge.context.aws.resources.ec2.ec2_instance import Ec2Instance
+from cloudrail.knowledge.context.aws.resources.ecs.ecs_task_definition import IEcsInstance, EcsTaskDefinition
+from cloudrail.knowledge.context.aws.resources.ec2.network_interface import NetworkInterface
+from cloudrail.knowledge.context.aws.resources.ec2.route import RouteTargetType, Route
+from cloudrail.knowledge.context.aws.resources.ec2.subnet import Subnet
+from cloudrail.knowledge.context.aws.resources.ec2.transit_gateway import TransitGateway
+from cloudrail.knowledge.context.aws.resources.ec2.transit_gateway_route import TransitGatewayRouteState, TransitGatewayRoute, TransitGatewayRouteType
 from cloudrail.knowledge.utils.utils import is_subset, compare_prefix_length, \
     has_intersection, is_ip_address, normalize_port_range, \
     get_all_ports_range, is_port_in_range
@@ -166,6 +166,7 @@ def _reduce_allowed_ports_for_ip_address_by_acls(rules: List[NetworkAclRule], ip
 
 def _reduce_ports_by_network_acl_rules(entries: List[NetworkAclRule], allowed_ports: List[Tuple[int, int]]) -> List[Tuple[int, int]]:
     nacl_allowed_ports = []
+    entries.sort(key=lambda x: x.rule_number)
     for entry in entries:
         port_range = [(entry.from_port, entry.to_port)]
         if nacl_allowed_ports and port_range:
@@ -367,8 +368,11 @@ def normalize_port_range_to_set(from_port: int, to_port: int) -> Set[int]:
 
 
 def convert_port_set_to_range_tuples(ports: set) -> List[Tuple[int, int]]:
-    if ports == get_all_ports() or len(ports) == 65536:
-        return [(0, 65535)]
+    return _convert_port_set_to_range_tuples(frozenset(ports))
+
+
+@functools.lru_cache(maxsize=None)
+def _convert_port_set_to_range_tuples(ports: frozenset) -> List[Tuple[int, int]]:
     if ports is None:
         return []
     port_list = list(ports)
@@ -376,7 +380,6 @@ def convert_port_set_to_range_tuples(ports: set) -> List[Tuple[int, int]]:
     return [(t[0][1], t[-1][1]) for t in
             (tuple(g[1]) for g in itertools.groupby(enumerate(port_list), lambda x: x[0] - x[1]))]
 
-
 @functools.lru_cache(maxsize=None)
 def get_all_ports():
     all_ports = set(range(0, 65535))
